/* ======================================
Project Title: Racial Heterogeneity in the U.S. Structural Transformation and Regional Convergence  
Authors: Minki Kim and Munseob Lee  
Last modified: Aug 4, 2023 

Cleaning the Census data  
====================================== */ 

cd "$datadir_proc"

/* ----------------------------------------------------- 
 Four different regions, as in Caselli and Coleman (2001) 
----------------------------------------------------- */
rename region region_detail
gen region=0

// North: Connecticut, Delaware, Massachusetts, Maryland, Maine, New Hampshire, New Jersey, New York, Pennsylvania, Rhode Island, Vermont
replace region = 1 if stateicp == 1 | stateicp == 2 | stateicp == 3 | stateicp == 4 | stateicp == 5 | stateicp == 6 | stateicp == 11 | stateicp == 12 | stateicp == 13 | stateicp == 14 | stateicp == 52   

// Midwest: Iowa, Illinois, Indiana, Kansas, Michigan, Minnesota, Missouri, North Dakota, Nebraska, Ohio, South Dakota, and Wisconsin.
replace region = 2 if stateicp == 31 | stateicp == 21 | stateicp == 22 | stateicp == 32 | stateicp == 23 | stateicp == 33 | stateicp == 34 | stateicp == 36 /// 
									 | stateicp == 35 | stateicp == 24 | stateicp == 37 | stateicp == 25   

// South: Alabama, Arkansas, Florida, Georgia, Kentucky, Louisiana, Mississippi, North Carolina, Oklahoma, South Carolina, Tennessee, Texas, Virginia, West Virginia
replace region = 3 if stateicp == 41 | stateicp == 42 | stateicp == 43 | stateicp == 44 | stateicp == 51 | stateicp == 45 | stateicp == 46 | stateicp == 47 /// 
									 | stateicp == 53 | stateicp == 48 | stateicp == 54 | stateicp == 49 | stateicp == 40 | stateicp == 56   
									 
// West: Arizona, California, Colorado, Idaho, Montana, Nevada, New Mexico, Oregon, Utah, Washington, and Wyoming
replace region = 4 if stateicp == 61 | stateicp == 71 | stateicp == 62 | stateicp == 63 | stateicp == 64 | stateicp == 65 | stateicp == 66 | stateicp == 72 /// 
									 | stateicp == 67 | stateicp == 73 | stateicp == 68    

drop if region==0
gen north = 0
gen midwest = 0
gen south = 0 
gen west = 0 
replace north=1 if region==1
replace midwest=1 if region==2
replace south=1 if region==3
replace west=1 if region==4

* Check
tab stateicp if north == 1 
tab stateicp if south == 1 

/* Further Cleaning */
drop if age < 16 /* Drop individuals whose age was less than 16 */
keep if empstat == 1 /* Drop individuals who were not employed */
drop if wkswork2 < 6 /* Drop individuals who had worked less than 50 weeks in the previous year */

/* ----------------------------------------------------- 
Identify South-North migrants
----------------------------------------------------- */
gen birth_south = 0 
gen mig_sn = 0 
gen mig_sn_black = 0 

* Birthplace code is different from stateicp code - need to do this manually 
* Birth region South: Alabama, Arkansas, Florida, Georgia, Kentucky, Louisiana, Mississippi, North Carolina, Oklahoma, South Carolina, Tennessee, Texas, Virginia, West Virginia
replace birth_south = 1 if bpl == 1 | bpl == 2 | bpl == 12 | bpl == 13 | bpl == 21 | bpl == 22 | bpl == 28 | bpl == 37 | bpl == 40 | bpl == 45 | bpl == 47 | bpl == 48 | bpl == 51 | bpl == 54
replace mig_sn = 1 if birth_south == 1 & region == 1 // South-to-North migrnats: born in the South but now working in the North 
replace mig_sn_black = 1 if birth_south == 1 & region == 1 & race == 2 // South-to-North black migrants

tab mig_sn_black year if region == 1, column // % of black migrants in the Northern US labor market 
tab mig_sn_black year if region == 1 & race == 2 , column // % of black migrants in the Northern US labor market 

* Sample without S-N black migrants 
drop if mig_sn_black == 1

/* -----------------------------------------------------
 Defining Agriculture and Nonagriculture 
----------------------------------------------------- */
/* agriculture = 1, non-agriculture = 2 */
drop if ind1950 == 0 // N/A or none reported
drop if ind1950 >= 970 // Nonclassifiable, not reported 
gen sector = 2
replace sector = 1 if ind1950 >= 100 & ind1950 < 200 // Agriculture and forestry 

gen agri=0
replace agri=1 if sector==1
gen nonagri=0
replace nonagri=1 if sector==2

label define agri_nonagri 1 "Agriculture" 2 "Non-agriculture"
label define region_name 1 "North" 2 "Midwest" 3 "South" 4 "West"
label values sector agri_nonagri
label value region region_name
save temp_emp, replace // Raw data to calculate employment shares

drop if incwage<=0 | incwage==999999 /* drop no wage information */
gen wage = incwage
save temp_wage, replace // Raw data to calculate average wages

/* -----------------------------------------------------
 Variables construction 
----------------------------------------------------- */
/* -----------------------------------
 Wage by year sector region 
 generated variable: wage^i_{st}: wage by sector and region
 wage: average wage of sector s in region i in year t 
----------------------------------- */
use temp_wage, clear
collapse (mean) wage [pw=perwt], by (year sector region) 
save temp_1_wage,replace

/* -----------------------------------
 Agri/Non-Agri share of employment by year region 
 generated variables: L^i_{st}: share of the labor force employed in sector s in region i 
 agri: employment share in agriculture in region i in year t 
 nonagri: employment share in non-agriculture in region i in year t 
----------------------------------- */
use temp_emp,clear
collapse (mean) agri nonagri [pw=perwt], by (year region)
save temp_1_emp,replace

/* -----------------------------------
 Agri/Non-Agri share of employment by year 
 generated variables: L_st: share of the labor force employed in sector s
 agri_yr: employment share in agriculture in year t 
 nonagri_yr: employment share in non-agriculture in year t
 
 This block generates the first panel of Table 1 
----------------------------------- */
use temp_emp,clear
collapse (mean) agri nonagri [pw=perwt], by (year)
rename agri agri_yr
rename nonagri nonagri_yr
save temp_1_emp1,replace

/* -----------------------------------
 Employed population share by year sector 
 generated variables: share of employed population in sector s in region i
 north1: north share of agricultural employment in year t
 north2: north share of non-agricultural employment in year t
----------------------------------- */
use temp_emp,clear
collapse (mean) north midwest south west [pw=perwt], by (year sector)
reshape wide north midwest south west, i(year) j(sector)
save temp_1_pop,replace

/* -----------------------------------
 Employed population share by year 
 generated variables: share of employed population in region i
 north: north share of employment in year t 
 south: south share of employment in year t 
----------------------------------- */
use temp_emp,clear
collapse (mean) north midwest south west [pw=perwt], by (year)
save temp_1_pop1,replace

/* Combine 5 datasets */
use temp_1_wage,clear
sort year region sector
merge m:1 year region using temp_1_emp, nogenerate
merge m:1 year using temp_1_emp1, nogenerate
merge m:1 year using temp_1_pop, nogenerate
merge m:1 year using temp_1_pop1, nogenerate
save temp_composite,replace // will use this data from now on 

/* -----------------------------------
 Removing interim datafiles
 ----------------------------------- */
cap rm temp_1_pop.dta
cap rm temp_1_pop1.dta
cap rm temp_1_emp1.dta
cap rm temp_emp.dta
cap rm temp1_emp1.dta
cap rm temp_1_emp.dta
cap rm temp_1_wage.dta
cap rm temp_wage.dta
