/* ======================================
Project Title: Racial Heterogeneity in the U.S. Structural Transformation and Regional Convergence  
Authors: Minki Kim and Munseob Lee  
Last modified: Aug 4, 2023 

This code does the decopomsition exercise (Eq. 3 in the paper)
====================================== */ 

cd "$datadir_proc"

/* -----------------------------------------------------
 Constructing w_i_j_t
 i = S, N
 j = f, m
----------------------------------------------------- */
use temp_composite.dta,clear
keep if year==`year_end'|year==`year_begin'
keep year region sector wage
sort year sector region
reshape wide wage, i(year sector) j(region)
reshape wide wage1 wage2 wage3 wage4, i(year) j(sector)
rename wage31 w_S_f
rename wage32 w_S_m
rename wage11 w_N_f
rename wage12 w_N_m
keep year w_S_f w_S_m w_N_f w_N_m
gen dummy=1
reshape wide w_S_f w_S_m w_N_f w_N_m, i(dummy) j(year)
save dec_w_i_s.dta,replace

/* -----------------------------------------------------
 Constructing L_i_f_t
 i = S, N 
----------------------------------------------------- */
use temp_composite.dta,clear
keep year region agri nonagri
keep if year==`year_end'|year==`year_begin'
duplicates drop year region, force 
keep year region agri
reshape wide agri, i(year) j(region)
rename agri3 L_S
rename agri1 L_N
keep year L_S L_N
gen dummy=1
reshape wide L_S L_N, i(dummy) j(year)
save dec_L_i.dta,replace

/* -----------------------------------------------------
 Constructing w_j_t
 j = f, m
----------------------------------------------------- */
use temp_composite,clear
sort year sector region
keep year sector region wage north1 midwest1 south1 west1 north2 midwest2 south2 west2 
reshape wide wage, i(year sector) j(region) // wage1: average wage of sector s in north in year t
gen wage_sector = 0

* Define sectoral wage = population-weighted average of regional average wages
replace wage_sector = wage1*north1+wage2*midwest1+wage3*south1+wage4*west1 if sector==1
replace wage_sector = wage1*north2+wage2*midwest2+wage3*south2+wage4*west2 if sector==2
keep year sector wage_sector
reshape wide wage_sector, i(year) j(sector)
gen wage_agri_relative = wage_sector1/wage_sector2
keep year wage_sector1 wage_sector2 wage_agri_relative

keep if year==`year_end'|year==`year_begin'
rename wage_sector1 w_f
rename wage_sector2 w_m
keep year w_f w_m
gen dummy=1
reshape wide w_f w_m, i(dummy) j(year)
save dec_w_s.dta,replace

/* -----------------------------------------------------
 Constructing w_i_t and w_t 
 i = S, N 
----------------------------------------------------- */
use temp_composite,clear
sort year region sector
reshape wide wage, i(year region) j(sector) // wage1: average agricultural wage in region i in year t

* Define regional average wage = equation (1) in Caselli-Coleman. weighted average of sectoral wage
gen wage_region = agri*wage1+nonagri*wage2
keep year region wage_region north midwest south west 
reshape wide wage_region, i(year) j(region)
gen wage_sum = wage_region1*north+wage_region2*midwest+wage_region3*south+wage_region4*west
gen wage_s_relative = wage_region3/wage_region1
gen wage_m_relative = wage_region2/wage_region1 
gen wage_w_relative = wage_region4/wage_region1

order year wage_s_relative wage_m_relative wage_w_relative

keep if year==`year_end'|year==`year_begin'
rename wage_region3 w_S
rename wage_region1 w_N
rename wage_sum w
keep year w_S w_N w
gen dummy=1
reshape wide w_S w_N w, i(dummy) j(year)
save dec_w.dta,replace

/* -----------------------------------------------------
 Merge all dataset 
----------------------------------------------------- */
use dec_w_i_s.dta,clear
merge 1:1 dummy using dec_L_i.dta
drop _merge
merge 1:1 dummy using dec_w_s.dta
drop _merge
merge 1:1 dummy using dec_w.dta
drop _merge


/* -----------------------------------------------------
 Constructing omegas 
 omega
 omega_i
 omega_i_j
----------------------------------------------------- */
gen omega_S_f`year_end'=(w_S_f`year_end'-w_f`year_end')/w`year_end'
gen omega_S_m`year_end'=(w_S_m`year_end'-w_m`year_end')/w`year_end'
gen omega_N_f`year_end'=(w_N_f`year_end'-w_f`year_end')/w`year_end'
gen omega_N_m`year_end'=(w_N_m`year_end'-w_m`year_end')/w`year_end'
gen omega_S_f`year_begin'=(w_S_f`year_begin'-w_f`year_begin')/w`year_begin'
gen omega_S_m`year_begin'=(w_S_m`year_begin'-w_m`year_begin')/w`year_begin'
gen omega_N_f`year_begin'=(w_N_f`year_begin'-w_f`year_begin')/w`year_begin'
gen omega_N_m`year_begin'=(w_N_m`year_begin'-w_m`year_begin')/w`year_begin'
gen omega_S`year_end'=(w_S_f`year_end'-w_S_m`year_end')/w`year_end'
gen omega_N`year_end'=(w_N_f`year_end'-w_N_m`year_end')/w`year_end'
gen omega_S`year_begin'=(w_S_f`year_begin'-w_S_m`year_begin')/w`year_begin'
gen omega_N`year_begin'=(w_N_f`year_begin'-w_N_m`year_begin')/w`year_begin'
gen omega`year_end'=(w_f`year_end'-w_m`year_end')/w`year_end'
gen omega`year_begin'=(w_f`year_begin'-w_m`year_begin')/w`year_begin'

/* -----------------------------------------------------
 Decomposition
 Following Equation B.3 in Caselli-Coleman (2001)
----------------------------------------------------- */
gen total = (w_S`year_end'-w_N`year_end')/w`year_end'-(w_S`year_begin'-w_N`year_begin')/w`year_begin'
gen total_percent = 100
gen channel1 = ((omega_S`year_end'+omega_S`year_begin')/2)*(L_S`year_end'-L_S`year_begin')-((omega_N`year_end'+omega_N`year_begin')/2)*(L_N`year_end'-L_N`year_begin')
display channel1
gen channel2 = (omega`year_end'-omega`year_begin')*((L_S`year_end'+L_S`year_begin')/2-(L_N`year_end'+L_N`year_begin')/2)
display channel2
gen channel3 = (omega_S_f`year_end'-omega_S_f`year_begin')*(L_S`year_end'+L_S`year_begin')/2+(omega_S_m`year_end'-omega_S_m`year_begin')*(1-(L_S`year_end'+L_S`year_begin')/2)-(omega_N_f`year_end'-omega_N_f`year_begin')*(L_N`year_end'+L_N`year_begin')/2-(omega_N_m`year_end'-omega_N_m`year_begin')*(1-(L_N`year_end'+L_N`year_begin')/2)
display channel3

/* -----------------------------------------------------
 Results
----------------------------------------------------- */
display total
display channel1+channel2+channel3 // Should be 1.0

gen dec1 = channel1/(channel1+channel2+channel3)*100 // Channel 1: Labor Reallocation
gen dec2 = channel2/(channel1+channel2+channel3)*100 // Channel 2: Between Industry
gen dec3 = channel3/(channel1+channel2+channel3)*100 // Channel 3: Within Industry

keep total total_percent channel* dec*

rename total total1
rename total_percent total2
rename channel1 lab1
rename dec1 lab2 
rename channel2 bet1
rename dec2 bet2
rename channel3 within1
rename dec3 within2
gen dummy = 1 
reshape long total lab bet within, i(dummy) j(j) 
drop j

rename total Total
rename lab Labor_Reallocation
rename bet Between_Industry
rename within Within_Industry

/* -----------------------------------------------------
 Remove interim files
----------------------------------------------------- */
cap rm dec_w_i_s.dta
cap rm dec_L_i.dta
cap rm dec_w_s.dta
cap rm dec_w.dta
