/* ======================================
Project Title: Racial Heterogeneity in the U.S. Structural Transformation and Regional Convergence  
Authors: Minki Kim and Munseob Lee  
Last modified: Aug 4, 2023 

This code repliates Table 1
====================================== */ 

clear all

* Directory
* For replicator: change the directory to your own local ones
local owndir = "C:\replication package"
global datadir_raw = "`owndir'/data/raw" // Raw data stored here
global datadir_proc = "`owndir'/data/proc" // Processed data stored here
global outputdir = "`owndir'/output"
global codedir = "`owndir'/code"

/* -----------------------------------
 Import raw data
----------------------------------- */
cd "$datadir_raw"
use census1940_2020_raw, clear

/* -----------------------------------
 Cleaning the raw data
----------------------------------- */
do "$codedir/DataClearing.do"
cd "$datadir_proc"

/* -----------------------------------
 Panel A, row 1
----------------------------------- */
use temp_composite,clear
keep year agri_yr nonagri_yr
duplicates drop year, force 
keep year agri_yr

save tab1_A_1, replace

/* -----------------------------------
 Panel A, row 2
----------------------------------- */
use temp_composite,clear
sort year sector region
keep year sector region wage north1 midwest1 south1 west1 north2 midwest2 south2 west2 
reshape wide wage, i(year sector) j(region) // wage1: average wage of sector s in north in year t, wage2: 

* Define sectoral wage = population-weighted average of regional average wages
gen wage_sector = 0
replace wage_sector = wage1*north1+wage2*midwest1+wage3*south1+wage4*west1 if sector==1
replace wage_sector = wage1*north2+wage2*midwest2+wage3*south2+wage4*west2 if sector==2
keep year sector wage_sector
reshape wide wage_sector, i(year) j(sector)

/* Agricultural relative wage */
gen wage_agri_relative = wage_sector1/wage_sector2
keep year wage_agri_relative

save tab1_A_2, replace

/* -----------------------------------
 Panel B
----------------------------------- */
use temp_composite,clear
sort year region sector
reshape wide wage, i(year region) j(sector) // wage1: average agricultural wage in region i in year t

* Define regional average wage = equation (1) in Caselli-Coleman. weighted average of sectoral wage
gen wage_region = agri*wage1+nonagri*wage2
keep year region wage_region north midwest south west 
reshape wide wage_region, i(year) j(region)
gen wage_sum = wage_region1*north + wage_region2*midwest + wage_region3*south + wage_region4*west
gen wage_s_relative = wage_region3/wage_region1
gen wage_m_relative = wage_region2/wage_region1 
gen wage_w_relative = wage_region4/wage_region1
keep year wage_s_relative wage_m_relative wage_w_relative

order year wage_s_relative wage_m_relative wage_w_relative

save tab1_B, replace 

/* -----------------------------------
 Entire Table 
----------------------------------- */
use tab1_A_1, clear
merge 1:1 year using tab1_A_2, nogenerate
merge 1:1 year using tab1_B, nogenerate

keep if year == 1940 | year == 1960 | year == 1980 | year == 2000 | year == 2020

rename year Year
rename agri_yr Agriculture_Share_of_Employment
rename wage_agri_relative Agricultural_Relative_Wage
rename wage_s_relative South_North_relative_wage
rename wage_m_relative Midwest_North_relative_wage
rename wage_w_relative West_North_relative_wage

xpose, clear varname
order _varname
format v* %9.3f
list, separator(1) ab(25)
export excel "$outputdir/Table1.xlsx", replace
save "$outputdir/Table1.dta", replace

cap rm tab1_A_1.dta
cap rm tab1_A_2.dta
cap rm tab1_B.dta

